==> haskell-expiring-cache-map-0.0.6.1-317-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-expiring-cache-map.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 expiring-cache-map
version:              0.0.6.1
visibility:           public
id:                   expiring-cache-map-0.0.6.1-AR9SfRqPKkpK4mrKQfy6lA
key:                  expiring-cache-map-0.0.6.1-AR9SfRqPKkpK4mrKQfy6lA
license:              BSD-3-Clause
copyright:            (c) 2014 Edward L. Blake
maintainer:           edwardlblake@gmail.com
author:               Edward L. Blake
homepage:             https://github.com/elblake/expiring-cache-map
synopsis:             General purpose simple caching.
description:
    A simple general purpose shared state cache map with automatic expiration
    of values, for caching the results of accessing a resource such as reading
    a file. With variations for Ord and Hashable keys using "Data.Map.Strict"
    and "Data.HashMap.Strict", respectively.

category:             Caching
abi:                  ddf134d01f826854d5b37113938bfd7a
exposed:              True
exposed-modules:
    Caching.ExpiringCacheMap.HashECM
    Caching.ExpiringCacheMap.Internal.Internal
    Caching.ExpiringCacheMap.Internal.Types
    Caching.ExpiringCacheMap.OrdECM Caching.ExpiringCacheMap.Types
    Caching.ExpiringCacheMap.Utils.TestSequence
    Caching.ExpiringCacheMap.Utils.Types

import-dirs:          /usr/lib/ghc-9.2.8/site-local/expiring-cache-map-0.0.6.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/expiring-cache-map-0.0.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-expiring-cache-map
hs-libraries:         HSexpiring-cache-map-0.0.6.1-AR9SfRqPKkpK4mrKQfy6lA
depends:
    base-4.16.4.0 containers-0.6.5.1
    hashable-1.4.3.0-BWGpbAVaWdFEBuRI2sTyFL
    unordered-containers-0.2.20-6SQIi6GiFzoJl2Kyo4GEMQ

haddock-interfaces:
    /usr/share/doc/haskell-expiring-cache-map/html/expiring-cache-map.haddock

haddock-html:         /usr/share/doc/haskell-expiring-cache-map/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-expiring-cache-map-0.0.6.1-322-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-expiring-cache-map.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 expiring-cache-map
version:              0.0.6.1
visibility:           public
id:                   expiring-cache-map-0.0.6.1-FIfhC5yG1rb3zKLFoqwzZE
key:                  expiring-cache-map-0.0.6.1-FIfhC5yG1rb3zKLFoqwzZE
license:              BSD-3-Clause
copyright:            (c) 2014 Edward L. Blake
maintainer:           edwardlblake@gmail.com
author:               Edward L. Blake
homepage:             https://github.com/elblake/expiring-cache-map
synopsis:             General purpose simple caching.
description:
    A simple general purpose shared state cache map with automatic expiration
    of values, for caching the results of accessing a resource such as reading
    a file. With variations for Ord and Hashable keys using "Data.Map.Strict"
    and "Data.HashMap.Strict", respectively.

category:             Caching
abi:                  90b01c2d99c789c49cfb6e12c38abaa2
exposed:              True
exposed-modules:
    Caching.ExpiringCacheMap.HashECM
    Caching.ExpiringCacheMap.Internal.Internal
    Caching.ExpiringCacheMap.Internal.Types
    Caching.ExpiringCacheMap.OrdECM Caching.ExpiringCacheMap.Types
    Caching.ExpiringCacheMap.Utils.TestSequence
    Caching.ExpiringCacheMap.Utils.Types

import-dirs:          /usr/lib/ghc-9.2.8/site-local/expiring-cache-map-0.0.6.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/expiring-cache-map-0.0.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-expiring-cache-map
hs-libraries:         HSexpiring-cache-map-0.0.6.1-FIfhC5yG1rb3zKLFoqwzZE
depends:
    base-4.16.4.0 containers-0.6.5.1
    hashable-1.4.4.0-KJ184tiZpE52U0PEHxyV1r
    unordered-containers-0.2.20-4hqmnCstShmJXjUlp61Lcu

haddock-interfaces:
    /usr/share/doc/haskell-expiring-cache-map/html/expiring-cache-map.haddock

haddock-html:         /usr/share/doc/haskell-expiring-cache-map/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
